@@ -61,7 +61,9 @@ class IdentificationView(BrowserView):
 
     question_filter = None
 
-    # default value is True, can be overwritten by certain conditions
+    # If False, an always_present risk will not have an explanation that no
+    # identification is necessary
+    # Default value is True, can be overwritten by certain conditions
     show_explanation_on_always_present_risks = True
 
     # default value for "always present" risks is "no", can be overwritten by certain conditions
@@ -83,6 +85,26 @@ class IdentificationView(BrowserView):
     def webhelpers(self):
         return api.content.get_view("webhelpers", self.context.aq_parent, self.request)
 
+    @property
+    @memoize
+    def default_collapsible_sections(self):
+        settings = self.webhelpers.content_country_obj
+        default_collapsible_sections = getattr(
+            settings,
+            "risk_default_collapsible_sections",
+            ["collapsible_section_information"],
+        )
+        return default_collapsible_sections
+
+    @memoize
+    def get_collapsible_section_state(self, collapsible_section_name):
+        return (
+            ""
+            if "collapsible_section_{0}".format(collapsible_section_name)
+            in self.default_collapsible_sections
+            else "closed"
+        )
+
     @property
     @memoize
     def session(self):
@@ -196,12 +218,19 @@ class IdentificationView(BrowserView):
 
             # Check if there was a change. If yes, touch the session
             changed = False
+            session = Session()
             if self.use_existing_measures and reply.get("handle_measures_in_place"):
-                session = Session()
-
                 new_measures = []
+                saved_solutions = {
+                    plan.solution_id: plan.used_in_training
+                    for plan in self.context.in_place_standard_measures
+                }
                 # First, check which of the standard solutions were selected
                 for solution in self.solutions:
+                    # If the solution was already added as a measure, retrieve the info
+                    # whether it was de-selected for the training, so that we don't
+                    # forcefully activate all measures for the training again.
+                    used_in_training = saved_solutions.get(solution.id, True)
                     if reply.get("measure-standard-%s" % solution.id):
                         new_measures.append(
                             model.ActionPlan(
@@ -209,6 +238,7 @@ class IdentificationView(BrowserView):
                                 requirements=solution.requirements,
                                 plan_type="in_place_standard",
                                 solution_id=solution.id,
+                                used_in_training=used_in_training,
                             )
                         )
                 # Clean up, remove all standard in-place measures. The active
@@ -256,9 +286,43 @@ class IdentificationView(BrowserView):
                     self.context.action_plans.extend(new_measures)
                     changed = True
 
-            if self.use_training_module and reply.get("handle_training_notes"):
-                self.context.training_notes = reply.get("training_notes")
-                changed = True
+            if self.use_training_module:
+                if reply.get("handle_training_notes"):
+                    self.context.training_notes = reply.get("training_notes")
+                    changed = True
+                # Case: the user has selected or de-selected a measure from the training slide
+                if reply.get("handle_training_measures_for"):
+                    # Gather all ids of the active measures, that means, where the checkboxes are ticked.
+                    # Remember: a measure that has been deselected (checkbox unticked) does not appear in
+                    # the REQUEST
+                    active_measures = set()
+                    for entry in reply:
+                        if entry.startswith("measure"):
+                            measure_id = entry.split("-")[-1]
+                            active_measures.add(measure_id)
+                    # Get the ids of all measures-in-place
+                    all_measures = set(
+                        [
+                            str(measure.id)
+                            for measure in list(self.context.in_place_standard_measures)
+                            + list(self.context.in_place_custom_measures)
+                        ]
+                    )
+                    # All measures that are not present in the REQUEST are deselected
+                    deselected_measures = all_measures - active_measures
+                    if active_measures:
+                        session.execute(
+                            "UPDATE action_plan set used_in_training=true where id in ({ids})".format(
+                                ids=",".join(active_measures)
+                            )
+                        )
+                    if deselected_measures:
+                        session.execute(
+                            "UPDATE action_plan set used_in_training=false where id in ({ids})".format(
+                                ids=",".join(deselected_measures)
+                            )
+                        )
+                    changed = True
 
             # This only happens on custom risks
             if reply.get("handle_custom_description"):
