@@ -1,35 +1,34 @@
-import unittest
+# coding=utf-8
 from euphorie.client.country import ClientCountry
+from euphorie.testing import EuphorieIntegrationTestCase
+from zope.annotation import IAttributeAnnotatable
+from zope.interface import implementer
 
 
-class ViewTests(unittest.TestCase):
-    def setUp(self):
-        from plone.folder.tests.layer import PloneFolderLayer
-        PloneFolderLayer.setUp()
-
-    def tearDown(Self):
-        from zope.testing.cleanup import cleanUp
-        cleanUp()
+class ViewTests(EuphorieIntegrationTestCase):
 
     def addSurvey(self, country, language, title):
         from euphorie.content.survey import Survey
         from euphorie.client.sector import ClientSector
         if "sector" not in country:
-            country["sector"] = ClientSector()
-            country["sector"].title = u"Test sector"
-            country["sector"].id = "sector"
-        sector = country["sector"]
+            sector = ClientSector(id='sector', title=u"Test sector")
+            country._setOb("sector", sector)
+        else:
+            sector = country["sector"]
         survey = Survey()
         survey.title = title
         survey.id = language
         survey.language = language
-        sector[language] = survey
+        sector._setOb('language', survey)
         return survey
 
     def surveys(self, country, language):
-        from euphorie.client.country import View
 
-        class Request:
+        @implementer(IAttributeAnnotatable)
+        class Request(object):
+            environ = {'REQUEST_METHOD': 'GET'}
+            form = {}
+
             def __init__(self, language):
                 self.language = language
 
@@ -38,8 +37,10 @@ class ViewTests(unittest.TestCase):
                     return self
                 raise AttributeError(key)
 
-        view = View(country, Request(language))
-        return view.surveys()
+        with self._get_view('view', country) as view:
+            view.request = Request(language)
+            view._updateSurveys()
+            return view.surveys
 
     def test_surveys_NoSurveys(self):
         country = ClientCountry()
@@ -53,14 +54,22 @@ class ViewTests(unittest.TestCase):
     def test_surveys_SameLanguage(self):
         country = ClientCountry()
         self.addSurvey(country, "en", u"Test survey")
-        self.assertEqual(self.surveys(country, "en"),
-                [{"id": "sector/en", "title": u"Test survey"}])
+        self.assertEqual(
+            self.surveys(country, "en"), [{
+                "id": "sector/en",
+                "title": u"Test survey"
+            }]
+        )
 
     def test_surveys_SurveyHasDialect(self):
         country = ClientCountry()
         self.addSurvey(country, "en-GB", u"Test survey")
-        self.assertEqual(self.surveys(country, "en"),
-                [{"id": "sector/en-GB", "title": u"Test survey"}])
+        self.assertEqual(
+            self.surveys(country, "en"), [{
+                "id": "sector/en-GB",
+                "title": u"Test survey"
+            }]
+        )
 
     def test_surveys_SkipPreview(self):
         country = ClientCountry()
