@@ -1,7 +1,7 @@
-from euphorie.deployment.tests.functional import EuphorieTestCase
+from euphorie.testing import EuphorieFunctionalTestCase
 
 
-class AddBarTileTests(EuphorieTestCase):
+class AddBarTileTests(EuphorieFunctionalTestCase):
     def _create(self, container, *args, **kwargs):
         newid = container.invokeFactory(*args, **kwargs)
         return getattr(container, newid)
@@ -27,11 +27,13 @@ class AddBarTileTests(EuphorieTestCase):
         self.assertEqual(action.title, u"Module")
 
     def testModuleNameInsideModule(self):
+        # To be able to determine what button label to display, we explicitly
+        # set the action.id to the fake "euphorie.submodule"
         self.loginAsPortalOwner()
         survey = self.createSurvey()
         module = self._create(survey, "euphorie.module", "module")
         tile = self.tile(module)
         tile.update()
-        action = filter(lambda fti: fti.id == "euphorie.module",
+        action = filter(lambda fti: fti.id == "euphorie.submodule",
                 tile.actions)[0]
         self.assertEqual(action.title, u"Submodule")
